@@ -156,7 +156,7 @@ public:
     void run() override
     {
         SolverInterface::ExitStatus result = m_solver->patsolve();
-        emit finished( result );
+        Q_EMIT finished( result );
     }
 
     void abort()
@@ -165,7 +165,7 @@ public:
         wait();
     }
 
-signals:
+Q_SIGNALS:
     void finished( int result );
 
 private:
@@ -197,14 +197,14 @@ void DealerScene::saveLegacyFile( QIODevice * io )
     xml.writeAttribute( QStringLiteral("started"), QString::number( m_dealStarted ) );
     xml.writeAttribute( QStringLiteral("data"), getGameState() );
 
-    foreach( const PatPile * p, patPiles() )
-    {
+    const auto patPiles = this->patPiles();
+    for (const PatPile * p : patPiles) {
         xml.writeStartElement( QStringLiteral("pile") );
         xml.writeAttribute( QStringLiteral("index"), QString::number( p->index() ) );
         xml.writeAttribute( QStringLiteral("z"), QString::number( p->zValue() ) );
 
-        foreach( const KCard * c, p->cards() )
-        {
+        const auto cards = p->cards();
+        for (const KCard * c : cards) {
             xml.writeStartElement( QStringLiteral("card") );
             xml.writeAttribute( QStringLiteral("suit"), QString::number( c->suit() ) );
             xml.writeAttribute( QStringLiteral("value"), QString::number( c->rank() ) );
@@ -240,7 +240,7 @@ bool DealerScene::loadLegacyFile( QIODevice * io )
     {
         QSet<int> suits;
         while ( !xml.atEnd() )
-            if ( xml.readNextStartElement() && xml.name() == "card" )
+            if (xml.readNextStartElement() && xml.name() == QLatin1String("card"))
                 suits << readIntAttribute( xml, QStringLiteral("suit") );
         options = QString::number( suits.size() );
 
@@ -258,18 +258,19 @@ bool DealerScene::loadLegacyFile( QIODevice * io )
     QString gameStateData = xml.attributes().value( QStringLiteral("data") ).toString();
 
     QMultiHash<quint32,KCard*> cards;
-    foreach ( KCard * c, deck()->cards() )
+    const auto deckCards = deck()->cards();
+    for (KCard * c : deckCards)
         cards.insert( (c->id() & 0xffff), c );
 
     QHash<int,PatPile*> piles;
-    foreach ( PatPile * p, patPiles() )
+    const auto patPiles = this->patPiles();
+    for (PatPile * p : patPiles)
         piles.insert( p->index(), p );
 
     // Loop through <pile>s.
     while ( xml.readNextStartElement() )
     {
-        if ( xml.name() != "pile" )
-        {
+        if (xml.name() != QLatin1String("pile")) {
             qCWarning(KPAT_LOG) << "Expected a \"pile\" tag. Found a" << xml.name() << "tag.";
             return false;
         }
@@ -289,8 +290,7 @@ bool DealerScene::loadLegacyFile( QIODevice * io )
         // Loop through <card>s.
         while ( xml.readNextStartElement() )
         {
-            if ( xml.name() != "card" )
-            {
+            if (xml.name() != QLatin1String("card")) {
                 qCWarning(KPAT_LOG) << "Expected a \"card\" tag. Found a" << xml.name() << "tag.";
                 return false;
             }
@@ -322,7 +322,7 @@ bool DealerScene::loadLegacyFile( QIODevice * io )
     setGameState( gameStateData );
 
 
-    emit updateMoves( moveCount() );
+    Q_EMIT updateMoves( moveCount() );
     takeState();
 
     return true;
@@ -369,8 +369,7 @@ void DealerScene::saveFile( QIODevice * io )
         if ( i == m_undoStack.size() )
             xml.writeAttribute( QStringLiteral("current"), QStringLiteral("true") );
 
-        foreach ( const CardStateChange & change, state->changes )
-        {
+        for (const CardStateChange & change : qAsConst(state->changes)) {
             xml.writeStartElement( QStringLiteral("move") );
             xml.writeAttribute( QStringLiteral("pile"), change.newState.pile->objectName() );
             xml.writeAttribute( QStringLiteral("position"), QString::number( change.newState.index ) );
@@ -378,14 +377,13 @@ void DealerScene::saveFile( QIODevice * io )
             bool faceChanged = !change.oldState.pile
                                || change.oldState.faceUp != change.newState.faceUp;
 
-            foreach ( const KCard * card, change.cards )
-            {
+            for (const KCard * card : change.cards) {
                 xml.writeStartElement( QStringLiteral("card") );
-                xml.writeAttribute( QStringLiteral("id"), QStringLiteral("%1").arg( card->id(), 7, 10, QChar('0') ) );
+                xml.writeAttribute( QStringLiteral("id"), QStringLiteral("%1").arg( card->id(), 7, 10, QLatin1Char('0') ) );
                 xml.writeAttribute( QStringLiteral("suit"), suitToString( card->suit() ) );
                 xml.writeAttribute( QStringLiteral("rank"), rankToString( card->rank() ) );
                 if ( faceChanged )
-                    xml.writeAttribute( QStringLiteral("turn"), change.newState.faceUp ? "face-up" : "face-down" );
+                    xml.writeAttribute( QStringLiteral("turn"), change.newState.faceUp ? QStringLiteral("face-up") : QStringLiteral("face-down") );
                 xml.writeEndElement();
             }
 
@@ -412,8 +410,7 @@ bool DealerScene::loadFile( QIODevice * io )
 
     xml.readNextStartElement();
 
-    if ( xml.name() != "kpat-game" )
-    {
+    if (xml.name() != QLatin1String("kpat-game")) {
         qCWarning(KPAT_LOG) << "First tag is not \"kpat-game\"";
         return false;
     }
@@ -422,19 +419,20 @@ bool DealerScene::loadFile( QIODevice * io )
     setGameOptions( xml.attributes().value( QStringLiteral("game-type-options") ).toString() );
 
     QMultiHash<quint32,KCard*> cardHash;
-    foreach ( KCard * c, deck()->cards() )
+    const auto cards = deck()->cards();
+    for (KCard * c : cards)
         cardHash.insert( c->id(), c );
 
     QHash<QString,KCardPile*> pileHash;
-    foreach ( KCardPile * p, piles() )
+    const auto piles = this->piles();
+    for (KCardPile * p : piles)
         pileHash.insert( p->objectName(), p );
 
     int undosToDo = -1;
 
     while( xml.readNextStartElement() )
     {
-        if ( xml.name() != "state" )
-        {
+        if (xml.name() != QLatin1String("state")) {
             qCWarning(KPAT_LOG) << "Expected a \"state\" tag. Found a" << xml.name() << "tag.";
             return false;
         }
@@ -444,13 +442,12 @@ bool DealerScene::loadFile( QIODevice * io )
 
         if ( undosToDo > -1 )
             ++undosToDo;
-        else if ( xml.attributes().value( QStringLiteral("current") ) == "true" )
+        else if ( xml.attributes().value( QStringLiteral("current") ) == QLatin1String("true") )
             undosToDo = 0;
         
         while( xml.readNextStartElement() )
         {
-            if ( xml.name() != "move" )
-            {
+            if (xml.name() != QLatin1String("move")) {
                 qCWarning(KPAT_LOG) << "Expected a \"move\" tag. Found a" << xml.name() << "tag.";
                 return false;
             }
@@ -469,8 +466,7 @@ bool DealerScene::loadFile( QIODevice * io )
 
             while ( xml.readNextStartElement() )
             {
-                if ( xml.name() != "card" )
-                {
+                if (xml.name() != QLatin1String("card")) {
                     qCWarning(KPAT_LOG) << "Expected a \"card\" tag. Found a" << xml.name() << "tag.";
                     return false;
                 }
@@ -482,9 +478,9 @@ bool DealerScene::loadFile( QIODevice * io )
                     return false;
                 }
 
-                if ( xml.attributes().value(QStringLiteral("turn")) == "face-up" )
+                if ( xml.attributes().value(QStringLiteral("turn")) == QLatin1String("face-up") )
                     card->setFaceUp( true );
-                else if ( xml.attributes().value(QStringLiteral("turn")) == "face-down" )
+                else if ( xml.attributes().value(QStringLiteral("turn")) == QLatin1String("face-down") )
                     card->setFaceUp( false );
                 
                 pile->insert( index, card );
@@ -498,7 +494,7 @@ bool DealerScene::loadFile( QIODevice * io )
     
     m_loadedMoveCount = 0;
     m_dealStarted = moveCount() > 0;
-    emit updateMoves( moveCount() );
+    Q_EMIT updateMoves( moveCount() );
 
     while ( undosToDo > 0 )
     {
@@ -506,7 +502,7 @@ bool DealerScene::loadFile( QIODevice * io )
         --undosToDo;
     }
     
-    foreach ( KCardPile * p, piles() )
+    for (KCardPile * p : piles)
         updatePileLayout( p, 0 );
 
     setAutoDropEnabled( reenableAutoDrop );
@@ -615,12 +611,12 @@ void DealerScene::cardsMoved( const QList<KCard*> & cards, KCardPile * oldPile,
 
     if ( oldPatPile && oldPatPile->isFoundation() && newPatPile && !newPatPile->isFoundation() )
     {
-        foreach ( KCard * c, cards )
+        for (KCard * c : cards)
             m_cardsRemovedFromFoundations.insert( c );
     }
     else
     {
-        foreach ( KCard * c, cards )
+        for (KCard * c : cards)
             m_cardsRemovedFromFoundations.remove( c );
     }
 
@@ -647,7 +643,8 @@ void DealerScene::startHint()
         setKeyboardModeActive( false );
 
     QList<QGraphicsItem*> toHighlight;
-    foreach ( const MoveHint & h, getHints() )
+    const auto moveHints = getHints();
+    for (const MoveHint & h : moveHints)
         toHighlight << h.card();
 
     if ( !m_winningMoves.isEmpty() )
@@ -660,7 +657,7 @@ void DealerScene::startHint()
 
     m_hintInProgress = !toHighlight.isEmpty();
     setHighlightedItems( toHighlight );
-    emit hintActive( m_hintInProgress );
+    Q_EMIT hintActive( m_hintInProgress );
 }
 
 
@@ -670,7 +667,7 @@ void DealerScene::stopHint()
     {
         m_hintInProgress = false;
         clearHighlightedItems();
-        emit hintActive( false );
+        Q_EMIT hintActive( false );
     }
 }
 
@@ -690,8 +687,8 @@ QList<MoveHint> DealerScene::getSolverHints()
     solver()->translate_layout();
     solver()->patsolve( 1 );
 
-    foreach ( const MOVE & m, solver()->firstMoves() )
-    {
+    const auto moves = solver()->firstMoves();
+    for (const MOVE & m : moves) {
         MoveHint mh = solver()->translateMove( m );
 	hintList << mh;
     }
@@ -704,8 +701,8 @@ QList<MoveHint> DealerScene::getHints()
         return getSolverHints();
 
     QList<MoveHint> hintList;
-    foreach (PatPile * store, patPiles())
-    {
+    const auto patPiles = this->patPiles();
+    for (PatPile * store : patPiles) {
         if (store->isFoundation() || store->isEmpty())
             continue;
 
@@ -718,8 +715,7 @@ QList<MoveHint> DealerScene::getHints()
         {
             if (allowedToRemove(store, (*iti)))
             {
-                foreach (PatPile * dest, patPiles())
-                {
+                for (PatPile * dest : patPiles) {
                     int cardIndex = store->indexOf(*iti);
                     if (cardIndex == 0 && dest->isEmpty() && !dest->isFoundation())
                         continue;
@@ -823,9 +819,10 @@ void DealerScene::startNew( int dealNumber )
 
     resetInternals();
 
-    emit updateMoves( 0 );
+    Q_EMIT updateMoves( 0 );
 
-    foreach( KCardPile * p, piles() )
+    const auto piles = this->piles();
+    for (KCardPile * p : piles)
         p->clear();
 
     m_dealInProgress = true;
@@ -867,14 +864,14 @@ void DealerScene::resetInternals()
     m_dropSpeedFactor = 1;
     m_cardsRemovedFromFoundations.clear();
 
-    foreach (KCard * c, deck()->cards())
-    {
+    const auto cards = deck()->cards();
+    for (KCard * c : cards) {
         c->disconnect( this );
         c->stopAnimation();
     }
 
-    emit solverStateChanged( QString() );
-    emit gameInProgress( true );
+    Q_EMIT solverStateChanged( QString() );
+    Q_EMIT gameInProgress( true );
 }
 
 QPointF posAlongRect( qreal distOnRect, const QRectF & rect )
@@ -902,12 +899,12 @@ void DealerScene::won()
     stopDemo();
     recordGameStatistics();
 
-    emit solverStateChanged( QString() );
+    Q_EMIT solverStateChanged( QString() );
 
-    emit newCardsPossible( false );
-    emit undoPossible( false );
-    emit redoPossible( false );
-    emit gameInProgress( false );
+    Q_EMIT newCardsPossible( false );
+    Q_EMIT undoPossible( false );
+    Q_EMIT redoPossible( false );
+    Q_EMIT gameInProgress( false );
 
     setKeyboardModeActive( false );
 
@@ -917,8 +914,8 @@ void DealerScene::won()
     qreal spacing = 2 * ( justOffScreen.width() + justOffScreen.height() ) / deck()->cards().size();
     qreal distOnRect = 0;
 
-    foreach ( KCard *c, deck()->cards() )
-    {
+    const auto cards = deck()->cards();
+    for (KCard *c : cards) {
         distOnRect += spacing;
         QPointF pos2 = posAlongRect( distOnRect, justOffScreen );
         QPointF delta = c->pos() - pos2;
@@ -941,7 +938,8 @@ void DealerScene::showWonMessage()
 
     // Hide all cards to prevent them from showing up accidentally if the 
     // window is resized.
-    foreach ( KCard * c, deck()->cards() )
+    const auto cards = deck()->cards();
+    for (KCard * c : cards)
         c->hide();
 
     updateWonItem();
@@ -1027,7 +1025,7 @@ void DealerScene::mousePressEvent( QGraphicsSceneMouseEvent * e )
     stop();
 
     const QList<QGraphicsItem *> itemsAtPoint = items( e->scenePos() );
-    KCard * card = qgraphicsitem_cast<KCard*>( itemsAtPoint.isEmpty() ? 0 : itemsAtPoint.first() );
+    KCard * card = qgraphicsitem_cast<KCard*>( itemsAtPoint.isEmpty() ? nullptr : itemsAtPoint.first() );
 
     if ( m_peekedCard )
     {
@@ -1050,7 +1048,7 @@ void DealerScene::mousePressEvent( QGraphicsSceneMouseEvent * e )
     {
         KCardScene::mousePressEvent( e );
         if ( !cardsBeingDragged().isEmpty() )
-            emit cardsPickedUp();
+            Q_EMIT cardsPickedUp();
     }
 }
 
@@ -1070,7 +1068,7 @@ void DealerScene::mouseReleaseEvent( QGraphicsSceneMouseEvent * e )
         bool hadCards = !cardsBeingDragged().isEmpty();
         KCardScene::mouseReleaseEvent( e );
         if ( hadCards && cardsBeingDragged().isEmpty() )
-            emit cardsPutDown();
+            Q_EMIT cardsPutDown();
     }
 }
 
@@ -1094,8 +1092,8 @@ bool DealerScene::tryAutomaticMove( KCard * card )
     {
         QList<KCard*> cardList = QList<KCard*>() << card;
 
-        foreach ( PatPile * p, patPiles() )
-        {
+        const auto patPiles = this->patPiles();
+        for (PatPile * p : patPiles) {
             if ( p->isFoundation() && allowedToAdd( p, cardList ) )
             {
                 moveCardToPile( card , p, DURATION_MOVE );
@@ -1147,8 +1145,7 @@ void DealerScene::undoOrRedo( bool undo )
         setGameState( m_currentState->stateData );
 
         QSet<KCardPile*> pilesAffected;
-        foreach ( const CardStateChange & change, changes )
-        {
+        for (const CardStateChange & change : changes) {
             CardState sourceState = undo ? change.newState : change.oldState;
             CardState destState = undo ? change.oldState : change.newState;
 
@@ -1160,8 +1157,7 @@ void DealerScene::undoOrRedo( bool undo )
 
             pilesAffected << sourceState.pile << destState.pile;
             
-            foreach ( KCard * c, change.cards )
-            {
+            for (KCard * c : change.cards) {
                 m_lastKnownCardStates.insert( c, destState );
 
                 c->setFaceUp( destState.faceUp );
@@ -1181,8 +1177,7 @@ void DealerScene::undoOrRedo( bool undo )
         // necessarily at the right positions within those piles. So we
         // run through the piles involved and swap card positions until
         // everything is back in its place, then relayout the piles.
-        foreach( KCardPile * p, pilesAffected )
-        {
+        for (KCardPile * p : qAsConst(pilesAffected)) {
             int i = 0;
             while ( i < p->count() )
             {
@@ -1196,9 +1191,9 @@ void DealerScene::undoOrRedo( bool undo )
             updatePileLayout( p, 0 );
         }
 
-        emit updateMoves( moveCount() );
-        emit undoPossible( !m_undoStack.isEmpty() );
-        emit redoPossible( !m_redoStack.isEmpty() );
+        Q_EMIT updateMoves( moveCount() );
+        Q_EMIT undoPossible( !m_undoStack.isEmpty() );
+        Q_EMIT redoPossible( !m_redoStack.isEmpty() );
 
         if ( m_toldAboutLostGame ) // everything's possible again
         {
@@ -1210,7 +1205,7 @@ void DealerScene::undoOrRedo( bool undo )
         int solvability = m_currentState->solvability;
         m_winningMoves = m_currentState->winningMoves;
 
-        emit solverStateChanged( solverStatusMessage( solvability, m_dealWasEverWinnable ) );
+        Q_EMIT solverStateChanged( solverStatusMessage( solvability, m_dealWasEverWinnable ) );
 
         if ( m_solver && ( solvability == SolverInterface::SearchAborted
                            || solvability == SolverInterface::MemoryLimitReached ) )
@@ -1234,8 +1229,8 @@ void DealerScene::takeState()
 
     QList<CardStateChange> changes;
 
-    foreach ( KCardPile * p, piles() )
-    {
+    const auto piles = this->piles();
+    for (KCardPile * p : piles) {
         QList<KCard*> currentRun;
         CardState oldRunState;
         CardState newRunState;
@@ -1298,9 +1293,9 @@ void DealerScene::takeState()
     }
     m_currentState = new GameState( changes, getGameState() );
 
-    emit redoPossible( false );
-    emit undoPossible( !m_undoStack.isEmpty() );
-    emit updateMoves( moveCount() );
+    Q_EMIT redoPossible( false );
+    Q_EMIT undoPossible( !m_undoStack.isEmpty() );
+    Q_EMIT updateMoves( moveCount() );
 
     m_dealWasJustSaved = false;
     if ( isGameWon() )
@@ -1311,8 +1306,8 @@ void DealerScene::takeState()
 
     if ( !m_toldAboutWonGame && !m_toldAboutLostGame && isGameLost() )
     {
-        emit gameInProgress( false );
-        emit solverStateChanged( i18n( "Solver: This game is lost." ) );
+        Q_EMIT gameInProgress( false );
+        Q_EMIT solverStateChanged( i18n( "Solver: This game is lost." ) );
         m_toldAboutLostGame = true;
         stopDemo();
         return;
@@ -1363,7 +1358,7 @@ void DealerScene::startDrop()
     m_dropInProgress = true;
     m_interruptAutoDrop = false;
     m_dropSpeedFactor = 1;
-    emit dropActive( true );
+    Q_EMIT dropActive( true );
 
     drop();
 }
@@ -1375,7 +1370,7 @@ void DealerScene::stopDrop()
     {
         m_dropTimer.stop();
         m_dropInProgress = false;
-        emit dropActive( false );
+        Q_EMIT dropActive( false );
 
         if ( autoDropEnabled() && m_takeStateQueued )
             m_interruptAutoDrop = true;
@@ -1391,8 +1386,8 @@ bool DealerScene::isDropActive() const
 
 bool DealerScene::drop()
 {
-    foreach ( const MoveHint & mh, getHints() )
-    {
+    const auto moveHints = getHints();
+    for (const MoveHint & mh : moveHints) {
         if ( mh.pile()
              && mh.pile()->isFoundation()
              && mh.priority() > 120
@@ -1401,14 +1396,13 @@ bool DealerScene::drop()
             QList<KCard*> cards = mh.card()->pile()->topCardsDownTo( mh.card() );
 
             QMap<KCard*,QPointF> oldPositions;
-            foreach ( KCard * c, cards )
+            for (KCard * c : qAsConst(cards))
                 oldPositions.insert( c, c->pos() );
 
             moveCardsToPile( cards, mh.pile(), DURATION_MOVE );
 
             int count = 0;
-            foreach ( KCard * c, cards )
-            {
+            for (KCard * c : qAsConst(cards)) {
                 c->completeAnimation();
                 QPointF destPos = c->pos();
                 c->setPos( oldPositions.value( c ) );
@@ -1428,7 +1422,7 @@ bool DealerScene::drop()
     }
 
     m_dropInProgress = false;
-    emit dropActive( false );
+    Q_EMIT dropActive( false );
 
     return false;
 }
@@ -1467,7 +1461,7 @@ void DealerScene::slotSolverEnded()
 
     m_solver->translate_layout();
     m_winningMoves.clear();
-    emit solverStateChanged( i18n("Solver: Calculating...") );
+    Q_EMIT solverStateChanged( i18n("Solver: Calculating...") );
     if ( !m_solverThread )
     {
         m_solverThread = new SolverThread( m_solver );
@@ -1485,7 +1479,7 @@ void DealerScene::slotSolverFinished( int result )
         m_dealWasEverWinnable = true;
     }
 
-    emit solverStateChanged( solverStatusMessage( result, m_dealWasEverWinnable ) );
+    Q_EMIT solverStateChanged( solverStatusMessage( result, m_dealWasEverWinnable ) );
 
     if ( m_currentState )
     {
@@ -1584,7 +1578,7 @@ void DealerScene::stopDemo()
     {
         m_demoTimer.stop();
         m_demoInProgress = false;
-        emit demoActive( false );
+        Q_EMIT demoActive( false );
     }
 }
 
@@ -1656,7 +1650,7 @@ void DealerScene::demo()
         return;
     }
 
-    emit demoActive( true );
+    Q_EMIT demoActive( true );
     takeState();
 }
 
@@ -1691,8 +1685,8 @@ void DealerScene::setSolver( SolverInterface *s) {
 
 bool DealerScene::isGameWon() const
 {
-    foreach (PatPile *p, patPiles())
-    {
+    const auto patPiles = this->patPiles();
+    for (PatPile *p : patPiles) {
         if (!p->isFoundation() && !p->isEmpty())
             return false;
     }
@@ -1844,11 +1838,12 @@ void DealerScene::setDeckContents( int copies, const QList<KCardDeck::Suit> & su
     // suit then rank ordering.
     QList<quint32> ids;
     unsigned int number = 0;
-    for ( int i = 0; i < copies; ++i )
-        foreach ( const KCardDeck::Rank & r, KCardDeck::standardRanks() )
-            foreach ( const KCardDeck::Suit & s, suits )
+    for (int i = 0; i < copies; ++i) {
+        const auto ranks = KCardDeck::standardRanks();
+        for (const KCardDeck::Rank & r : ranks)
+            for (const KCardDeck::Suit & s : suits)
                 ids << KCardDeck::getId( s, r, number++ );
-
+    }
     deck()->setDeckContents( ids );
 }
 
@@ -1857,12 +1852,13 @@ QImage DealerScene::createDump() const
 {
     const QSize previewSize( 480, 320 );
 
-    foreach ( KCard * c, deck()->cards() )
+    const auto cards = deck()->cards();
+    for (KCard * c : cards)
         c->completeAnimation();
 
     QMultiMap<qreal,QGraphicsItem*> itemsByZ;
-    foreach ( QGraphicsItem * item, items() )
-    {
+    const auto items = this->items();
+    for (QGraphicsItem * item : items) {
         Q_ASSERT( item->zValue() >= 0 );
         itemsByZ.insert( item->zValue(), item );
     }
@@ -1871,8 +1867,7 @@ QImage DealerScene::createDump() const
     img.fill( Qt::transparent );
     QPainter p( &img );
 
-    foreach ( QGraphicsItem * item, itemsByZ )
-    {
+    for (QGraphicsItem * item : qAsConst(itemsByZ)) {
         if ( item->isVisible() )
         {
             p.save();
@@ -1964,11 +1959,11 @@ void DealerScene::addCardForDeal( KCardPile * pile, KCard * card, bool faceUp, Q
 void DealerScene::startDealAnimation()
 {
     qreal speed = sqrt( width() * width() + height() * height() ) / ( DURATION_DEAL );
-    foreach ( PatPile * p, patPiles() )
-    {
+    const auto patPiles = this->patPiles();
+    for (PatPile * p : patPiles) {
         updatePileLayout( p, 0 );
-        foreach ( KCard * c, p->cards() )
-        {
+        const auto cards = p->cards();
+        for (KCard * c : cards) {
             if ( !m_initDealPositions.contains( c ) )
                 continue;
 
