@@ -62,11 +62,11 @@ public:
 QList<KCardTheme> KCardTheme::findAll()
 {
     QList<KCardTheme> result;
-    QStringList indexFiles = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("carddecks"), QStandardPaths::LocateDirectory );
-    Q_FOREACH (const QString &index, indexFiles) {
+    const QStringList indexFiles = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("carddecks"), QStandardPaths::LocateDirectory );
+    for (const QString &index : indexFiles) {
         const QStringList entries = QDir(index).entryList(QDir::Dirs);
-        Q_FOREACH (const QString &d, entries) {
-            QString indexFilePath = index + '/' + d + "/index.desktop";
+        for (const QString &d : entries) {
+            QString indexFilePath = index + QLatin1Char('/') + d + QLatin1String("/index.desktop");
             if (QFile::exists(indexFilePath)) {
                 QString directoryName = QFileInfo( indexFilePath ).dir().dirName();
                 KCardTheme t( directoryName );
@@ -83,11 +83,11 @@ QList<KCardTheme> KCardTheme::findAll()
 QList<KCardTheme> KCardTheme::findAllWithFeatures( const QSet<QString> & neededFeatures )
 {
     QList<KCardTheme> result;
-    QStringList indexFiles = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("carddecks"), QStandardPaths::LocateDirectory );
-    Q_FOREACH (const QString &index, indexFiles) {
+    const QStringList indexFiles = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("carddecks"), QStandardPaths::LocateDirectory );
+    for (const QString &index : indexFiles) {
         const QStringList entries = QDir(index).entryList(QDir::Dirs);
-        Q_FOREACH (const QString &d, entries) {
-            QString indexFilePath = index + '/' + d + "/index.desktop";
+        for (const QString &d : entries) {
+            QString indexFilePath = index + QLatin1Char('/') + d + QLatin1String("/index.desktop");
             if (QFile::exists(indexFilePath)) {
                 QString directoryName = QFileInfo( indexFilePath ).dir().dirName();
                 KCardTheme t( directoryName );
